@@ -122,8 +122,10 @@ mon addr = 127.0.0.1:%(port)d
         # Create and start monitor
         self._exec(mon_opts + ["--mkfs"])
         self._touch(os.path.join(mondir, "done"))
-        mon, _ = self._exec(mon_opts,
-                            wait_for_line=b"mon.a@0(leader).mds e1 print_map")
+        mon, _ = self._exec(
+            mon_opts,
+            wait_for_line=r"mon.a@0\(leader\).mds e1 print_map")
+
         self.addCleanup(self._kill, mon.pid)
 
         # Create and start OSD
@@ -132,9 +134,9 @@ mon addr = 127.0.0.1:%(port)d
                                 "root=default"])
         self._exec(osd_opts + ["--mkfs", "--mkjournal"])
         if version < pkg_resources.parse_version("0.94.0"):
-            wait_for_line = b"journal close"
+            wait_for_line = "journal close"
         else:
-            wait_for_line = b"done with init"
+            wait_for_line = "done with init"
         osd, _ = self._exec(osd_opts, wait_for_line=wait_for_line)
         self.addCleanup(self._kill, osd.pid)
 
